using System;
using System.IO;
using Foxit.PDF;
using Foxit.PDF.PageElements;

namespace Web_CSharp.GeneratorExamples
{
	public partial class FormattedTextContinuation : System.Web.UI.Page
	{
		// Template for document elements
		private static Template template = new Template();
		private static bool imageSet = false;

		static FormattedTextContinuation()
		{
			// Uncomment the line below to add a layout grid to the pages
			//template.Elements.Add( new LayoutGrid() );

			// Add the page numbering label to the page template 
			PageNumberingLabel pageNumLabel = new PageNumberingLabel( "Page %%CP%% of %%TP%%", 0, 494, 684, 10, Font.Helvetica, 10, TextAlign.Center );
			template.Elements.Add( pageNumLabel );
		}

		private void SetImage()
		{
			// Adds the image to the page template if it has not already been added
			// This is done because MapPath cannot be used from a static constructor
			if( !imageSet )
			{
				Image image = new Image( MapPath( "../Images/FoxitLogo.png" ), 342, 0, 0.18f );
				image.Align = Align.Center;
				template.Elements.Add( image );
				imageSet = true;
			}
		}

		protected void Page_Load(object sender, System.EventArgs e)
		{
			// Sets the page template if needed
			SetImage();

			// Read the contents of the Formatted file			
			string formattedText = GetTextFromFile( MapPath( "../Text/FormattedText.txt" ) );

			// Create a document and set it's properties
			Foxit.PDF.Document document = new Foxit.PDF.Document();
			document.Creator = "FormattedTextContinuation.aspx";
			document.Author = "Foxit Software";
			document.Title = "Formatted Text Continuation";

			// Add the template to the document
			document.Template = template;

			// Create an FormattedTextAreaStyle and set the initial properties for the FormattedTextArea
			FormattedTextAreaStyle style = new FormattedTextAreaStyle( FontFamily.Helvetica, 10, false );
			style.Paragraph.Indent = 36;
			style.Paragraph.SpacingAfter = 6;
			style.Paragraph.AllowOrphanLines = false;
			
			// Create an FormattedTextArea using the style
			FormattedTextArea formattedTextArea = new FormattedTextArea( formattedText, 0, 60, 315, 424, style );
			
			// Loop untill all of the text is displayed
			while( formattedTextArea != null )
			{
				formattedTextArea = AddTextToDocument( document, formattedTextArea );
			}
			
			// Outputs the document to the current web page
			document.DrawToWeb( "FormattedTextContinuation.pdf" );
		}

		private FormattedTextArea AddTextToDocument( Document document, FormattedTextArea formattedTextArea )
		{
			// Create a new page
			Foxit.PDF.Page page = new Foxit.PDF.Page( PageSize.Letter, PageOrientation.Landscape, 54.0f );
			
			// Add left column FormattedTextArea to page
			page.Elements.Add( formattedTextArea );
			
			// Create the right column FormattedTextArea
			formattedTextArea = formattedTextArea.GetOverflowFormattedTextArea( 369, 60 );
			
			// Add it to the page if it had overflow text
			if( formattedTextArea != null )
			{
				page.Elements.Add( formattedTextArea );
			}
			
			// Add page to document
			document.Pages.Add( page );
			
			// Return the next FormattedTextArea if there is overflow text
			if( formattedTextArea == null )
			{
				return null;
			}
			else
			{
				return formattedTextArea.GetOverflowFormattedTextArea( 0, 60 );
			}
		}

		private string GetTextFromFile( string filePath )
		{
			// Opens a text file and returns the text from it.
			StreamReader textFile = File.OpenText( filePath );
			string sectionText = textFile.ReadToEnd();
			textFile.Close();
			return sectionText;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
		}
		#endregion
	}
}
